clear all
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUT PART
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

L = 1310;
nxval = 200; dxval = (L+1)/nxval;
xval = 0:dxval:L;
mz_vec = [12937, 12937, 12937, 12937, 12937, 12937];

rho = 1.25; B = 18.3;   bz = 0.2; St = 0.16; lambda = 3.5; D = 3.25;   aL = 0.233; 
sigma_CL = 3.9234/(sqrt(lambda/bz));
sigma_qz_hatt = sigma_CL*(D/B);

% Use constant Kaz ? 
Kamax = 2.4112;
Constant_Kaz = Kamax*4*(D/B)^2;          % If Constant_Kaz=0, it will compute Kaz for every wind-speed setting   
                                % based on Kamax. If constant Kaz should be used, assign its value.

N_mod = 6;              % Number of eigenmodes
%N_j = 3;               % Number of tuned mass dampers (given in text-file)




% Eigenfrequencies [omega_z1,omega_z2,....,omega_z(N_mod)]:
%omega_z = [0.71,0.9,1.27,1.36,1.76,2.14];
% Spread omega_z = [1,2,3,4,5,6];
omega_z = [1.50,1.55,1.60,1.65,1.70,1.75];

% Damping [xi_z1,xi_z2,...,xi_z(N_mod)]:
xi_z = [0.005,0.0051,0.0058,0.006,0.0077,0.01];

% Eigenmodes:
v = [3 4 6 7 10 12];            % Which of the eigenmodes is vertical
k_pi = 1:1:16;                  % Value of sine wave

% Load text file with eigenmodes:
load -ascii MatLabInPutFiles\AA.txt
K=length(AA(1,:));
N=length(AA(:,1)); 
ak = zeros(length(v),K);
for k = 1:length(v) 
ak(k,:) = AA(4*(v(k))-1,:);
end

% Eigenmodes [phi_z1, phi_z2, ...., phi_z(N_mod)]:
phi_z = @(x) [sum(ak(1,:)*sin(k_pi(:)*pi*x/L)),sum(ak(2,:)*sin(k_pi(:)*pi*x/L)),sum(ak(3,:)*sin(k_pi(:)*pi*x/L)),sum(ak(4,:)*sin(k_pi(:)*pi*x/L)),sum(ak(5,:)*sin(k_pi(:)*pi*x/L)),sum(ak(6,:)*sin(k_pi(:)*pi*x/L))];

phi_val = [];
phi_xval = xval';
for j = 1:length(xval)
phi_val = [phi_val; phi_z(xval(j))];
end
clear AA SS
[max_val_phi,first_element_nr_max] = max(abs(phi_val));
location_first_max = xval(first_element_nr_max);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input data which in this case is given in files:
%
% N_j                   Number of TMD's
% x_d                   Position(s) of TMD(s)
% TMD_mode_damp         Which vertical mode the TMD(s) is tuned to damp
% my_d                  TMD(s) mass ratio
% xi_d                  TMD(s) damping ratio
% omega_d               TMD(s) eigen-frequency
%                       (The files is loaded in the "output-part")
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% Make movie?
make_movie = 0;         % If make_movie=1, it will make movie, if make_movie=0 it will not. 





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUT PART
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Plot of vertical eigenmodes:
vm = length(v);
fig = figure;
for n=1:vm,
    j=v(n); 
    str=['\phi_{' num2str(j) '}'];
    Phizi = phi_val(:,n)/max(abs(phi_val(:,n))); 
    subplot(vm,1,n);
    p = plot(xval,Phizi,'-');
    axis([0, L, -1.2, 1.2])
    grid
    hYLabel = ylabel( str);
    hYLabelProperties(hYLabel)
    if n == vm
        hXLabel = xlabel('x');
        hXLabelProperties(hXLabel)
    end
    hold on
end
hTitle = title('Vertical mode shapes, \phi_{z}(x/L)');
PlotProperties(fig, p, hTitle, hXLabel, hYLabel)
screen2png(['MatLabOutPutFiles\VerticalModes'])

% Get N_j, TMD_mode_damp and x_d from text file:
% One single TMD:
     load -ascii MatLabInPutFiles\TMDnumberAndPositionsSingleMode.txt
        N_j_vec_single_mode = TMDnumberAndPositionsSingleMode(:,1);
        TMD_mode_damp_vec_single_mode = TMDnumberAndPositionsSingleMode(:,2);
        x_d_vec_single_mode = TMDnumberAndPositionsSingleMode(:,3);
        clear TMDnumberAndPositionsSingleMode
% Multiple TMD's:
     load -ascii MatLabInPutFiles\TMDnumberAndPositionsMultiMode.txt
        N_j_vec_multi_mode = TMDnumberAndPositionsMultiMode(:,1);
        TMD_mode_damp_vec_multi_mode = TMDnumberAndPositionsMultiMode(:,2:4);
        x_d_vec_multi_mode = TMDnumberAndPositionsMultiMode(:,5:7);
        clear TMDnumberAndPositionsMultiMode



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Making omega- axis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   nomega = 10;
   diff_small_large = 2; % Difference between small and large omega steps
   step_omega_n = 0.25*((omega_z(1)+omega_z(N_mod))/2);
   omega_min = omega_z(1)-step_omega_n;
   omega_max = omega_z(1)+step_omega_n;
   
   domega_large_approx = 0.5*step_omega_n/(nomega); % Approximate domega_large
   domega_small = 0.5*step_omega_n/(diff_small_large*nomega+0.5);
   n_steps_small = ceil((2*step_omega_n/domega_small)+1);
   omega_small = zeros(N_mod,n_steps_small);
   for n = 1:N_mod
     omega_small(n,:) = omega_z(n)-step_omega_n:domega_small:omega_z(n)+step_omega_n;
   end
   Omega_start = omega_z(1)-2*step_omega_n+0.5*domega_large_approx:domega_large_approx:omega_z(1)-step_omega_n-0.5*domega_large_approx;
      Omega = Omega_start;
      omega_small_n = omega_small(1,:);
      m_max = length(omega_small(1,:))-1;
   for n = 1:N_mod-1
       omega_small_n_plus_1 = omega_small(n+1,:);
       for m = 1:m_max
       if omega_small_n(m)>omega_small_n_plus_1(m_max-m)
           omega_small_n = omega_small_n(1:m-1);
           omega_small_n_plus_1 = omega_small_n_plus_1(m_max-m+1:numel(omega_small_n_plus_1));
           break                                                
       end   
       end
   
       delta_large = omega_small_n_plus_1(1)-omega_small_n(end);
       n_steps_large = ceil(delta_large/domega_large_approx);
       domega_large = delta_large/n_steps_large; 
       omega_large = omega_small_n(end)+0.5*domega_large:domega_large:omega_small_n_plus_1(1)-domega_large;
       
       if n == N_mod-1
           omega_large = [omega_large, omega_small_n_plus_1];
       end
       Omega =[Omega, omega_small_n, omega_large];
       omega_small_n = omega_small_n_plus_1;
       m_max = length(omega_small_n)-1;
   end
   dOmega = zeros(size(Omega));
   for n = 2:length(Omega)-1
       dOmega(n) = 0.5*(Omega(n+1)-Omega(n-1));
   end
   dOmega(1) = 2*0.5*(Omega(2)-Omega(1));
   dOmega(end) = 2*0.5*(Omega(end)-Omega(end-1));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Running different cases 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
LocationMode1 = [1;0;0;0;0;0]; LocationMode2 = [0;1;0;0;0;0]; LocationSeveralModes = [0;0;1;0;0;0]; 
MassRatio = [0;0;0;1;0;0]; DampingTMD = [0;0;0;0;1;0]; FrequencyTMD = [0;0;0;0;0;1];
CaseStudy = [LocationMode1, LocationMode2, LocationSeveralModes, MassRatio, DampingTMD, FrequencyTMD];
n_parameters = length(CaseStudy(1,:));

TotCaseNr = 0;
number_of_cases = 5;

Information_matrix = zeros(n_parameters*number_of_cases,17);
% Write information in the following format:
% Case , N_j , x_d (1x(1->3)-vector) , TMD_mode_damp (1x(1->3)-vector) , my_d
% (1x(1->3)-vector) , xi_d (1x(1->3)-vector) , omega_d (1x(1->3)-vector)

% Make the size of the critical-wind-speed for each mode (Vr), 
% and the omega_s - vectors: 
Vr = zeros(1,N_mod);
Omega_s = zeros(1,N_mod);



H_rz = zeros(length(Omega), N_mod, N_mod, n_parameters*number_of_cases);
H_orig = zeros(length(Omega), N_mod, N_mod, n_parameters*number_of_cases);

maxmaxrz_orig = zeros(1,number_of_cases*n_parameters); 
maxstdrz_orig = zeros(1,number_of_cases*n_parameters);
maxkp_orig = zeros(1,number_of_cases*n_parameters);

maxmaxrz = zeros(1,number_of_cases*n_parameters); 
maxstdrz = zeros(1,number_of_cases*n_parameters);
maxkp = zeros(1,number_of_cases*n_parameters);

maxmaxrd = zeros(1,number_of_cases*n_parameters); 
maxstdrd = zeros(1,number_of_cases*n_parameters);
maxkp_rd = zeros(1,number_of_cases*n_parameters);

for Parameter = 1:n_parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   CaseToStudy = CaseStudy(Parameter,:);
   
    if CaseToStudy(1)==1
    % Get N_j, TMD_mode_damp and x_d from text file:
        N_j_vec = N_j_vec_single_mode(1:number_of_cases,1);
        TMD_mode_damp_vec = TMD_mode_damp_vec_single_mode(1:number_of_cases,:);
        x_d_vec = x_d_vec_single_mode(1:number_of_cases,:); 
        
    elseif CaseToStudy(2)==1
    % Get N_j, TMD_mode_damp and x_d from text file:
        N_j_vec = N_j_vec_single_mode(number_of_cases+1:2*number_of_cases,1);
        TMD_mode_damp_vec = TMD_mode_damp_vec_single_mode(number_of_cases+1:2*number_of_cases,:);
        x_d_vec = x_d_vec_single_mode(number_of_cases+1:2*number_of_cases,:); 
        
    elseif CaseToStudy(3)==1
        % Get N_j, TMD_mode_damp and x_d from text file:
        N_j_vec = N_j_vec_multi_mode(1:number_of_cases,1);
        TMD_mode_damp_vec = TMD_mode_damp_vec_multi_mode(1:number_of_cases,:);
        x_d_vec = x_d_vec_multi_mode(1:number_of_cases,:); 
    else
        N_j_vec = 3*ones(number_of_cases,1);
        TMD_mode_damp_vec = repmat([1,2,1],[number_of_cases,1]);
        x_d_vec = repmat([300, 600, 900],[number_of_cases,1]);
    end
    for Case = 1:number_of_cases %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     TotCaseNr = TotCaseNr + 1;
    
    if CaseToStudy(4)==1
    % Get weight between TMD's mass ratios from text file:
        biggest_mass_ratio = 0.005;
        load -ascii MatLabInPutFiles\TMDmassRatio.txt
        my_d_vec = biggest_mass_ratio*TMDmassRatio;
        clear TMDmassRatio
    else
        my_d_vec_first_row = zeros(1,N_j_vec(Case));
        for n = 1:N_j_vec(Case)
        my_d_vec_first_row(n) = 0.005;
        end
        my_d_vec = repmat(my_d_vec_first_row,[number_of_cases,1]);
    end
 
        my_d = my_d_vec(Case,:);
    if CaseToStudy(5)==1
        % Calculate TMD damping ratio(s) in a seperate Matlab script (Xis.m)
        xi_d_vec = Xis(my_d_vec);
    else
        % Use Den Hartog:
        xi_d_vec_first_row = zeros(1,N_j_vec(Case));
        for n = 1:N_j_vec(Case)
        xi_d_vec_first_row(n) = sqrt((3*my_d(n))/(8*(1+my_d(n))^3)); 
        end
        xi_d_vec = repmat(xi_d_vec_first_row,[number_of_cases,1]);
    end
    if CaseToStudy(6)==1
        % Calculate TMD frequency in a seperate Matlab script (Omegas.m):
    omega_d_vec = Omegas(my_d_vec,TMD_mode_damp_vec,omega_z);
    else
        % Use Den Hartog:
        omega_d_vec_first_row = zeros(1,N_j_vec(Case));
        for n = 1:N_j_vec(Case)
        omega_d_vec_first_row(Case,n) = omega_z(TMD_mode_damp_vec(n))/sqrt(1+(3/2)*my_d_vec(Case,n)); 
        end
        omega_d_vec = repmat(omega_d_vec_first_row,[number_of_cases,1]);
    end
        
% All parameters to be used:
    N_j = N_j_vec(Case,:);
    TMD_mode_damp = TMD_mode_damp_vec(Case,:);
    x_d = x_d_vec(Case,:);
    my_d = my_d_vec(Case,:);
    xi_d = xi_d_vec(Case,:);
    omega_d = omega_d_vec(Case,:);

% Values of eigenmodes at damper positions:
phi_d = zeros(N_j,N_mod);
    for n = 1:N_j
           phi_d(n,:)=phi_z(x_d(n));
    end

% Integral of phi_z^2
int_phi_z_sq = zeros(1,N_mod);
dn = 0.01;
for n = 0:dn:L
    int_phi_z_sq = int_phi_z_sq + (phi_z(n)).^2*dn;
end

% Modal mass matrix:
Mz = zeros(N_mod);
for n = 1:N_mod
    Mz(n,n) = mz_vec(n)*int_phi_z_sq(n);
end
% TMD modal mass matrix:
Md = zeros(N_j);
for m = 1:N_j
       Md(m,m) = my_d(m)*Mz(TMD_mode_damp(m),TMD_mode_damp(m)); 
end
  
% Some matrixes to be used later on:
  % Sqz_original = zeros(length(Omega),N_mod);                    
 % SRzRz_original = zeros(N_mod,length(Omega),N_mod);
                                                                Sqz = zeros(length(Omega),N_mod);
                                                                SRzRz = zeros(N_mod,length(Omega),N_mod);
  SR_original = zeros(N_mod,N_mod,length(Omega),N_mod);         SR = zeros(N_mod+N_j,N_mod+N_j,length(Omega),N_mod);
  Hinv_original = zeros(N_mod,N_mod,length(Omega),N_mod);       H11 = zeros(N_mod,N_mod,length(Omega),N_mod);
  H_original = zeros(N_mod,N_mod,length(Omega),N_mod);          H12 = zeros(N_mod,N_j,length(Omega),N_mod);
  Sr_original = zeros(length(Omega),N_j,N_mod);                 H21 = zeros(N_j,N_mod,length(Omega),N_mod);
  S_eta_original = zeros(N_mod,N_mod,length(Omega),N_mod);      H22 = zeros(N_j,N_j,length(Omega),N_mod);
  Psi_original = zeros(1,N_mod,N_j);                            Hinv = zeros(N_mod+N_j,N_mod+N_j,length(Omega),N_mod);
  sigma_rz_original = zeros(N_j,N_mod);                         H = zeros(N_mod+N_j,N_mod+N_j,length(Omega),N_mod);
  xi_aez_original = zeros(1,N_mod);                             Sr = zeros(1+N_j,1+N_j,length(Omega),N_mod,N_j);
  xiz_original = zeros(N_mod,N_mod,N_mod);                      S_eta = zeros(N_mod+N_j,N_mod+N_j,length(Omega),N_mod);
  xi_aez_orig = zeros(N_j,N_mod,N_mod);                         xi_aez = zeros(N_mod,N_mod);
                                                                Psi = zeros(N_j+1,N_mod+N_j,N_j);
  % Make the bottom part of the Psi - matrix:
  for n = 1:N_j
     Psi(1+n,N_mod+n,:) = 1; 
  end
  
Kaz = zeros(N_mod,N_mod);        
sigma_rz_guess_original = 0;
n_loops = zeros(N_j,N_mod);
Convergence_sigma_rz_all = [];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% For every wind-speed setting
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for v = 1:N_mod
        Vr(v) = (D*omega_z(v))/(2*pi*St);
        
if Constant_Kaz == 0
for n = 1:N_mod
    if Vr(v)/Vr(n) < 0.9 || Vr(v)/Vr(n) > 2.45
        Kaz(n,v) = 0;
    else
        Kaz(n,v) = (4*(D/B)^2)*Kamax*(0.9/(((Vr(v)/Vr(n))-0.25)^(2)))*exp(-1/(((Vr(v)/Vr(n))+0.02)^(24)))-0.18;
    end
end
else 
    for n = 1:N_mod
    Kaz(n,v) = Constant_Kaz;
    end
end
      V = Vr(v);
      
      Omega_s(v) = (2*pi*V*St)/D;
      omega_s = Omega_s(v);
      
     
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % Response without mass damper: 
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     Kzinv = zeros(N_mod,N_mod);
    for n = 1:N_mod
    Kzinv(n,n) = (1/(omega_z(n)^2*Mz(n,n)));
    end
    for xr = 1:N_j
        error = 1;
        Convergence_sigma_rz = [sigma_rz_guess_original];
while error > 0.001
        n_loops(xr,v) = n_loops(xr,v) + 1;
    for n = 1:N_mod 
    xi_aez_original(1,n) = ((rho*B^2)/(4*mz_vec(v)))*Kaz(n,v)*(1-(sigma_rz_guess_original/(aL*D)).^2);
    xiz_original(n,n,v) = (xi_z(n)-xi_aez_original(1,n));
    end
    omega_z_rel = zeros(N_mod,N_mod,length(Omega));
    % For every omega- setting:
   for o = 1:length(Omega)
  omega = Omega(o);
   
   for n = 1:N_mod
   omega_z_rel(n,n,o) = omega*(1/(omega_z(n)));
   end
   
   Sqz(o,v) = (((0.5*rho*B*sigma_qz_hatt*V^2)^2)/(sqrt(pi)*omega_s*bz))*exp(-((1-omega/omega_s)/bz)^2);
   for m = 1:N_mod
   SRzRz(m,o,v) = 2*lambda*D*Sqz(o,v)*int_phi_z_sq(m);
  
   SR_original(m,m,o,v) = (Kzinv(m,m)^2*SRzRz(m,o,v));
   end
   
   Hinv_original(:,:,o,v) = eye(N_mod)-omega_z_rel(:,:,o)^2*eye(N_mod)+2*1i*omega_z_rel(:,:,o)*xiz_original(:,:,v);
   H_original(:,:,o,v) = inv(Hinv_original(:,:,o,v));
   
    
   Psi_original(1,1:N_mod,xr) = phi_z(x_d(xr));
   
   Sr_original(o,xr,v) = Psi_original(:,:,xr)*conj(H_original(:,:,o,v))*SR_original(:,:,o,v)*transpose(H_original(:,:,o,v))*transpose(Psi_original(:,:,xr));
   S_eta_original(:,:,o,v) = conj(H_original(:,:,o,v))*SR_original(:,:,o,v)*transpose(H_original(:,:,o,v));
  end
 
    % Computing the standard deviation:
      sigma_rzrz_original_itt = abs(sqrt(trapz(transpose(Sr_original(:,xr,v)).*dOmega)));
  
        error = abs(sigma_rzrz_original_itt - sigma_rz_guess_original);
        sigma_rz_guess_original = sigma_rzrz_original_itt;
        Convergence_sigma_rz = [Convergence_sigma_rz, sigma_rzrz_original_itt]; 
end
if xr == 1
Convergence_sigma_rz_all = [Convergence_sigma_rz_all, Convergence_sigma_rz]; 
end
xi_aez_orig(xr,:,v) = xi_aez_original(1,:);   
sigma_rz_original(xr,v) = sigma_rzrz_original_itt;  
if sigma_rzrz_original_itt < 0
    return
end
    end   
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % Response with TMD (Tuned mass damper): 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
  % For every omega- setting:
   omega_z_rel = zeros(N_mod,N_mod,length(Omega));
   omega_d_rel = zeros(N_j,N_j,length(Omega));
  for o = 1:length(Omega)
  omega = Omega(o);
  
    xiz = zeros(N_mod,N_mod);
    Kzinv = zeros(N_mod,N_mod);
   for n = 1:N_mod
   omega_z_rel(n,n,o) = omega*(1/(omega_z(n)));
   xi_aez(n,v) = (rho*B^2/(4*mz_vec(v)))*Kaz(n,v); 
   xiz(n,n) = (xi_z(n)-xi_aez(n,v));
   Kzinv(n,n) = (1/(omega_z(n)^2*Mz(n,n)));
   end
  
   xid = zeros(N_j,N_j);
   for n = 1:N_j
       omega_d_rel(n,n,o) = omega*(1/omega_d(n));
       xid(n,n) = xi_d(n);
   end
  
   Sqz(o,v) = (((0.5*rho*B*sigma_qz_hatt*V^2)^2)/(sqrt(pi)*omega_s*bz))*exp(-((1-omega/omega_s)/bz)^2);
   for m = 1:N_mod
   SRzRz(m,o,v) = 2*lambda*D*Sqz(o,v)*int_phi_z_sq(m);
  
   SR(m,m,o,v) = (Kzinv(m,m)^2*SRzRz(m,o,v));
   end
   
   Dhatt = inv(Mz)*transpose(phi_d)*Md;
   H11(:,:,o,v) = eye(N_mod)-omega_z_rel(:,:,o)^2*(eye(N_mod)+Dhatt*phi_d)+2*1i*omega_z_rel(:,:,o)*xiz;
   H12(:,:,o,v) = -omega_z_rel(:,:,o)^2*Dhatt;
   H21(:,:,o,v) = -omega_d_rel(:,:,o)^2*phi_d;
   H22(:,:,o,v) = eye(N_j)-omega_d_rel(:,:,o)^2+2*1i*omega_d_rel(:,:,o).*xid;
   
   Hinv(:,:,o,v) = [H11(:,:,o,v),H12(:,:,o,v);H21(:,:,o,v),H22(:,:,o,v)];
   H(:,:,o,v) = inv(Hinv(:,:,o,v));
   
    for xr = 1:N_j
   Psi(1,1:N_mod,xr) = phi_z(x_d(xr));
   
   Sr(:,:,o,v,xr) = Psi(:,:,xr)*conj(H(:,:,o,v))*SR(:,:,o,v)*transpose(H(:,:,o,v))*transpose(Psi(:,:,xr));
   S_eta(:,:,o,v) = conj(H(:,:,o,v))*SR(:,:,o,v)*transpose(H(:,:,o,v));
    end
    
  end
 
end
    
% End of "for all wind- speed setting"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
% Make a plot of convergence of original response:
if TotCaseNr ==1
    fig = figure;
    start = 1;
for v = 1:min(N_mod,6) 
    subfig = subplot(3,2,v);
     % pos = [0.06,0.51,0.26, 0.425; 
      %      0.37,0.51, 0.26, 0.425; 
       %     0.68,0.51,0.26,0.425;
        %    0.06,0.05 ,0.26,0.425;
         %   0.37,0.05,0.26,0.425;
          %  0.68,0.05,0.26,0.425];
        %set(subfig, 'position', pos(v,:))
yplotval = Convergence_sigma_rz_all(start:start+n_loops(1,v));
xplotval = 0:1:n_loops(1,v);
start = start + length(yplotval);
p = plot(xplotval,yplotval);
set(p,'LineWidth',2.5);
    if v == 1
    hTitle = title('Convergence of $$\sigma_{r_{z}}$$ itterations of system without TMD','HorizontalAlignment','left');
    set(hTitle, ...
    'interpreter','latex','FontName','Times','FontSize',22);
    end
hXLabel = xlabel('Number of itterations');
hYLabel = ylabel('$$\sigma_{r_{z}}$$   [m]');
set([hXLabel, hYLabel], ...
    'interpreter','latex','FontName','Times','FontSize',16);
end
FigProperties(fig)

end   
  
 % Splitting Sr_rz and Sr_rd: 
  Sr_rz = zeros(length(Omega),N_j, N_mod);
  S_eta_rz = zeros(N_mod,length(Omega), N_mod);
  S_eta_rd = zeros(N_j,length(Omega), N_mod);
  Sr_rd = zeros(length(Omega),N_j, N_mod);
  for o = 1:length(Omega)
  for v = 1:N_mod
      for xr = 1:N_j
      Sr_rz(o,xr,v) = Sr(1,1,o,v,xr);
      Sr_rd(o,xr,v) = Sr(1+xr,1+xr,o,v,xr);
      end
      for n = 1:N_mod
      S_eta_rz(n,o,v) = S_eta(n,n,o,v);
      end
      for n = 1:N_j
      S_eta_rd(n,o,v) = S_eta(N_mod+n,N_mod+n,o,v);
      end
  end
  end
   %clear Sr S_eta
    
  % Computing the standard deviation:
  sigma_rzrz = zeros(N_j, N_mod);
  sigma_rdrd = zeros(N_j, N_mod);
  for v = 1:N_mod
  for xr = 1:N_j
      sigma_rzrz(xr, v) = abs(sqrt(trapz(transpose(Sr_rz(:,xr,v)).*dOmega)));
      sigma_rdrd(xr, v) = abs(sqrt(trapz(transpose(Sr_rd(:,xr,v)).*dOmega)));
  end
  end
  
  % For every "mean wind speed at resonance"- setting:
  %........................................................
  % Compute:
  % * Response spectral densities
  % * Max/min values to be used in plotting  
    min_x = 0.95*min(Omega); max_x = 1.05*max(Omega);
 

x_d_legend_line_rd_matr = zeros(length(Omega),N_j,N_mod);   
x_d_legend_dotted_rd_matr = zeros(length(Omega),N_j,N_mod);
S_rdrd_dotted_matr = zeros(length(Omega),N_j,N_mod);
x_d_legend_dotted_matr = zeros(length(Omega),N_j,N_mod);
S_rzrz_dotted_matr = zeros(length(Omega),N_j,N_mod);
x_d_legend_line_matr = zeros(length(Omega),N_j,N_mod); 

S_rzrz_original_matr = zeros(length(Omega),N_j,N_mod);

S_rzrz_line_matr = zeros(length(Omega),N_j,N_mod);
S_rdrd_line_matr = zeros(length(Omega),N_j,N_mod);
  for v = 1:N_mod
%             S_rzrz_rel = zeros(length(Omega),N_j);
%             S_rdrd_rel = zeros(length(Omega),N_j);
%             max_y = 0;
%       for xr = 1:N_j
%             S_rzrz_rel(:,xr) = abs(Sr_rz(:,xr,v))/(sigma_rzrz(xr,v)^2);
%             max_y_new_rz = max(abs(Sr_rz(:,xr,v))/(sigma_rzrz(xr,v)^2));
%             
%             S_rdrd_rel(:,xr) = abs(Sr_rd(:,xr,v))/(sigma_rdrd(xr,v)^2);
%             max_y_new_rd = max(abs(Sr_rd(:,xr,v))/(sigma_rdrd(xr,v)^2));
%             
%             max_y_new = max(max_y_new_rz,max_y_new_rd);
%       if max_y_new > max_y
%             max_y = max_y_new;       
%       end
%       end
%       
      % Finding for which xr the response is equal:
      % * Sigma_rzrz_rel:
            mn = ones(N_j,1);
      for m = 1:N_j
          for n = 1:N_j
              if  m<n
              if abs(S_rzrz_rel(:,m)-S_rzrz_rel(:,n)) < 10^(-4) 
                  mn(n) = 0;
              end
              end
          end
      end
      
      % * Sigma_rdrd_rel:
            jk = ones(N_j, N_j,1);
       
     for j = 1:N_j
          for k = 1:N_j
              if  j<k
              if abs(S_rdrd_rel(:,j)-S_rdrd_rel(:,k)) < 10^(-4) 
                  jk(n) = 0;
              end
              end
          end
      end
  
      
        % Where the response is equal another response -> make dotted line in plot: 
        % * rz: 
        S_rzrz_line = [];
        S_rzrz_dotted = [];
             x_d_legend_line = [];
             x_d_legend_dotted = [];
        for n = 1:N_j
            if mn(n) == 1
              S_rzrz_line = [S_rzrz_line, Sr_rz(:,n,v)];
             x_d_legend_line = [x_d_legend_line, x_d(n)/L];  
            end
            if mn(n) == 0
              S_rzrz_dotted = [S_rzrz_dotted, Sr_rz(:,n,v)];
             x_d_legend_dotted = [x_d_legend_dotted, x_d(n)/L];
            end
        end
      x_d_legend_rz = [x_d_legend_line, x_d_legend_dotted];
          
       % * rd:
        S_rdrd_line = [];
        S_rdrd_dotted = [];
             x_d_legend_line_rd = [];
             x_d_legend_dotted_rd = [];
        for n = 1:N_j
            if mn(n) == 1
              S_rdrd_line = [S_rdrd_line, Sr_rd(:,n,v)];
             x_d_legend_line_rd = [x_d_legend_line_rd, x_d(n)/L];  
            end
            if mn(n) == 0
               S_rdrd_dotted = [S_rdrd_dotted, Sr_rz(:,n,v)];
             x_d_legend_dotted_rd = [x_d_legend_dotted_rd, x_d(n)/L];
            end
        end
      x_d_legend_rd = [x_d_legend_line_rd, x_d_legend_dotted_rd];
       
      % For the original response of main system without TMD:
      % * rz: 
        S_rzrz_original = [];
        for n = 1:N_j
            if mn(n) == 1
              S_rzrz_original = [S_rzrz_original,  abs(Sr_original(:,n,v))];
            end
          
        end
         
        
% Store the computed S-specra in a matrix for each v- and xr- setting:
for xr = 1:N_j
x_d_legend_line_rd_matr(:,xr,v) = x_d(xr);
x_d_legend_line_matr(:,xr,v) = x_d(xr);

S_rzrz_line_matr(:,xr,v) = Sr_rz(:,xr,v);
S_rdrd_line_matr(:,xr,v) = Sr_rd(:,xr,v);

S_rzrz_original_matr(:,xr,v) =  Sr_original(:,xr,v);
if isempty(S_rdrd_dotted) == 0
S_rdrd_dotted_matr(:,xr,v) = S_rdrd_dotted(:,xr);
x_d_legend_dotted_rd_matr(:,xr,v) = x_d(xr);
end

if isempty(S_rzrz_dotted) == 0
S_rzrz_dotted_matr(:,xr,v) = S_rzrz_dotted(:,xr);
x_d_legend_dotted_matr(:,xr,v) = x_d(xr);    
end
end
%clear Sr_rz Sr_rd S_rdrd_dotted;
  end

     for n = 1:N_mod
     for o = 1:length(Omega)
         H_rz(o,n,v,TotCaseNr) = H(n,n,o,v);
         H_orig(o,n,v,TotCaseNr) = H_original(n,n,o,v);
     end
     end
    clear H H_original
  
  
 
  for xr = 1:N_j   

    S_rdrd_line_plot = [];
    S_rdrd_dotted_plot = [];
    S_rzrz_original_plot = [];
  
    S_rzrz_line_plot = [];
    S_rzrz_dotted_plot = [];
    legend_wind_speed1 = [];
    legend_wind_speed2 = [];
 
  for v = 1:N_mod
        S_rdrd_line_plot = [S_rdrd_line_plot, S_rdrd_line_matr(:,xr,v)];
        S_rzrz_line_plot = [S_rzrz_line_plot, S_rzrz_line_matr(:,xr,v)];
        
        S_rzrz_original_plot = [S_rzrz_original_plot, S_rzrz_original_matr(:,xr,v)];
      legend_wind_speed1 = [legend_wind_speed1, v];
      legend_wind_speed2 = [legend_wind_speed2, round(100*Vr(v))/100];
  end   
  if x_d(xr) == L/2 || x_d(xr) == L/4
 % Plotting of S_rzrz:
        titletextS = ['Response of main system for Case ' num2str(TotCaseNr) ' , at $$x_{r}$$ = ' num2str(x_d(xr)) ' m'];
        ylabeltextS = ['$$ S_{r_{z}}$$'];
     PlotResponseSpectra(S_rzrz_line_plot,Omega,legend_wind_speed1,legend_wind_speed2,min_x,max_x,TotCaseNr,xr,x_d,titletextS,ylabeltextS); 
 % Plotting of S_rdrd:
        titletextS = ['Response of TMD for Case ' num2str(TotCaseNr) ' , at $$x_{r}$$ = ' num2str(x_d(xr)) ' m'];
        ylabeltextS = ['$$ S_{r_{d}}$$'];
     PlotResponseSpectra(S_rdrd_line_plot,Omega,legend_wind_speed1,legend_wind_speed2,min_x,max_x,TotCaseNr,xr,x_d,titletextS,ylabeltextS);
 % Plotting of S_rzrz original (without TMD):
        titletextS = ['Response of original system without TMD at $$x_{r}$$ = ' num2str(x_d(xr)) ' m'];
        ylabeltextS = ['$$ S_{r_{z}}$$'];
     PlotResponseSpectra(S_rzrz_original_plot,Omega,legend_wind_speed1,legend_wind_speed2,min_x,max_x,TotCaseNr,xr,x_d,titletextS,ylabeltextS);    
     
  end     
  end
clear S_rdrd_line_matr S_rzrz_line_matr S_rzrz_original_matr S_rdrd_line_plot S_rzrz_line_plot S_rzrz_original_plot 
clear legend_wind_speed1   legend_wind_speed2


 % Time domain simulation
 
jn = 12; % jn = number of time domain simulations
dt = 0.1; 
time = 0:dt:600;   
t_sim = 0:dt:20;

tn = length(time);
t_simn = length(t_sim); 
 
rz = zeros(jn,tn,N_j,N_mod);    rd = zeros(jn,tn,N_j,N_mod);    rz_orig = zeros(jn,tn,N_j,N_mod);        
k_p = zeros(jn,N_j,N_mod);      k_p_rd = zeros(jn,N_j,N_mod);   k_p_orig = zeros(jn,N_j,N_mod);
maxrz = zeros(jn,N_j,N_mod);    maxrd = zeros(jn,N_j,N_mod);    maxrz_orig = zeros(jn,N_j,N_mod);  
meanrz = zeros(jn,N_j,N_mod);   meanrd = zeros(jn,N_j,N_mod);   meanrz_orig = zeros(jn,N_j,N_mod);
stdrz = zeros(jn,N_j,N_mod);    stdrd = zeros(jn,N_j,N_mod);    stdrz_orig = zeros(jn,N_j,N_mod);
    
 
 phi_mode = phi_val;
 rand_vec = zeros(jn,length(Omega));
     for o = 1:length(Omega)
         rand_vec(j,o) = 2*pi*rand;
     end
 for v =1:N_mod
  
 for j = 1:jn
    rz_sum = zeros(1,tn);
    rd_sum = zeros(1,tn); 
    rz_sum_orig = zeros(1,tn);
    
    % Make the rand-matrix
 

 
     
 for xr = 1:N_j;
   
%if x_d(xr) == L/2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
 for k=1:length(Omega)
    omegak=Omega(k);
    dOmegak = dOmega(k);
    Srzk = Sr_rz(k,xr,v);   
    
    rz_sum = rz_sum+sqrt(2*Srzk*dOmegak)*cos(omegak*time+rand_vec(j,k)); 
    
    Srdk = Sr_rd(k,xr,v);
    rd_sum = rd_sum+sqrt(2*Srdk*dOmegak)*cos(omegak*time+rand_vec(j,k));
    
    Srzorigk = Sr_original(k,xr,v);
    rz_sum_orig = rz_sum_orig+sqrt(2*Srzorigk*dOmegak)*cos(omegak*time+rand_vec(j,k));
 end
    
rz(j,:,xr,v) = rz_sum; 
maxrz(j,xr,v) = max(abs(rz(j,:,xr,v)));  
meanrz(j,xr,v) = mean((rz(j,:,xr,v)));
stdrz(j,xr,v) = std(rz(j,:,xr,v));
k_p(j,xr,v) = max(abs(rz(j,:,xr,v)))/std(rz(j,:,xr,v)); 

rz_sum = zeros(1,tn);    

rd(j,:,xr,v) = rd_sum; 
maxrd(j,xr,v) = max(abs(rd(j,:,xr,v)));  
meanrd(j,xr,v) = mean((rd(j,:,xr,v)));
stdrd(j,xr,v) = std(rd(j,:,xr,v));
k_p_rd(j,xr,v) = max(abs(rd(j,:,xr,v)))/std(rd(j,:,xr,v)); 

rd_sum = zeros(1,tn);

rz_orig(j,:,xr,v) = rz_sum_orig; 
maxrz_orig(j,xr,v) = max(abs(rz_orig(j,:,xr,v)));  
meanrz_orig(j,xr,v) = mean((rz_orig(j,:,xr,v)));
stdrz_orig(j,xr,v) = std(rz_orig(j,:,xr,v));
k_p_orig(j,xr,v) = max(abs(rz_orig(j,:,xr,v)))/std(rz_orig(j,:,xr,v)); 

rz_sum_orig = zeros(1,tn);

end
end
 
if v == 1 
if TotCaseNr == 1 || TotCaseNr == 20 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Statistics on original system without TMD
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
titletext_orig = ['Statistics from   ' num2str(jn) '  simulations for main system without TMD'];
PlotStatistics(maxrz_orig,stdrz_orig,k_p_orig,L/2,N_j,x_d,v,jn,time,rz_orig,titletext_orig);

maxmaxrz_orig(TotCaseNr) = max(maxrz_orig(:,xr,v));
maxstdrz_orig(TotCaseNr) = max(stdrz_orig(:,xr,v));
maxkp_orig(TotCaseNr) = max(k_p_orig(:,xr,v));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Statistics system with TMD
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
titletext_rz = ['Statistics from   ' num2str(jn) '  simulations for Case ' num2str(TotCaseNr) ''];
PlotStatistics(maxrz,stdrz,k_p,L/2,N_j,x_d,v,jn,time,rz,titletext_rz);

maxmaxrz(TotCaseNr) = max(maxrz(:,xr,v));
maxstdrz(TotCaseNr) = max(stdrz(:,xr,v));
maxkp(TotCaseNr) = max(k_p(:,xr,v));

titletext_rd = ['Statistics from   ' num2str(jn) '  simulations for Case ' num2str(TotCaseNr) ''];
PlotStatistics_Rd(maxrz,stdrz,k_p,L/2,N_j,x_d,v,jn,time,rz,titletext_rd);

maxmaxrd(TotCaseNr) = max(maxrd(:,xr,v));
maxstdrd(TotCaseNr) = max(stdrd(:,xr,v));
maxkp_rd(TotCaseNr) = max(k_p_rd(:,xr,v));
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plotting of time series:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if x_d(xr) == L/2 || x_d(xr) == L/4
  % Plotting of r_z with TMD installed (Done in a separate Matlab- script (PlotTimeSeries.m)):      
  titletextTS = ['Time domain simulation of $r_{z}$ with TMD installed, Case' num2str(TotCaseNr) ' at x = ' num2str(x_d(xr)) ' m, $$V_{cr}$$ =' num2str(round(1000*Vr(v))/1000) ''];
  PlotTimeSeries(time,rz,maxrz,stdrz,k_p,TotCaseNr,jn,xr,x_d,v,titletextTS);
  
  % Plotting of r_d with TMD installed (Done in a separate Matlab- script (PlotTimeSeriesRd.m)):
  titletextTS_Rd = ['Time domain simulation of $r_{d}$ with TMD installed, Case' num2str(TotCaseNr) ' at x = ' num2str(x_d(xr)) ' m, $$V_{cr}$$ =' num2str(round(1000*Vr(v))/1000) ''];
  PlotTimeSeriesRd(time,rd,maxrd,stdrd,k_p,TotCaseNr,jn,xr,x_d,v,titletextTS_Rd);
  
  % Plotting of original r_z without TMD installed (Done in a separate Matlab- script (PlotTimeSeriesOrig.m)):
  titletextTS_orig = ['Time domain simulation of original $r_{z}$ without TMD at x = ' num2str(x_d(xr)) ' m, $$V_{cr}$$ =' num2str(round(1000*Vr(v))/1000) ''];
  PlotTimeSeriesOrig(time,rz_orig,maxrz_orig,stdrz_orig,k_p_orig,TotCaseNr,jn,xr,v,titletextTS_orig);
    end
end
end
 end
    


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot of max statistical values in different cases:
% Y1 = [];
% Y2 = [];
% Y3 = [];
% for casenr = 1:TotCaseNr
% Y1 = [Y1; maxmaxrz_orig(casenr)];
% Y2 = [Y2; maxmaxrz(casenr)];
% Y3 = [Y3; maxmaxrd(casenr)];
%  end
% width1 = 0.5; width2 = width1/2; width3 = width2/4; 
% 
% fig = figure;
% bary1 = bar(Y1,width1);               
% hold on
% bary2 = bar(Y2,width2);       
% bary3 = bar(Y3,width3);
%                      
% hold off
% set(bary1,'FaceColor','r','EdgeColor','r');
% set(bary2,'FaceColor','b','EdgeColor','b');
% set(bary3,'FaceColor','g','EdgeColor','g');
% hLegend = legend('Without TMD' ,'Main system', 'TMDs');
% hTitle = title('Maximum response for each case');
% hYLabel = ylabel('Max response    [m] ');
% hXLabel = xlabel('Case');
% BarPlotProperties(fig, hTitle, hXLabel, hYLabel);
% screen2png('MatLabOutPutFiles\MaxResponseRzRdCases');
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%  rz_mode = zeros(length(t_sim),N_mod,N_mod);
%  rz_mode_orig = zeros(length(t_sim),N_mod,N_mod);
%  rz_mode_shape = zeros(length(t_sim),length(xval),N_mod,N_mod); 
%  rz_mode_shape_orig = zeros(length(t_sim),length(xval),N_mod,N_mod);

 eta_n  = zeros(length(t_sim),N_mod);
 eta_rd_n = zeros(length(t_sim),N_j);
 eta_orig_n = zeros(length(t_sim),N_mod);

 
%%%%%%%%%%%%%%%%%%%%%%%%
% MOVIE
%%%%%%%%%%%%%%%%%%%%%%%
make_movie = 1;
 for v = 1:N_mod   
max_rz = 0;
j_max_rz = 1;
for js = 1:jn
    max_rz_new = max(max(real(abs(rz(js,1:t_simn,:,v)))));
    if max_rz_new > max_rz
    max_rz = max_rz_new;
    j_max_rz = js;
    end
end

 


for j = j_max_rz
 for n = 1:N_mod
     eta_sum = zeros(1,t_simn);
     eta_sum_original = zeros(1,t_simn);
     
 for k=1:length(Omega)
    omegak=Omega(k);
    dOmegak = dOmega(k);  
    
    Setak = S_eta_rz(n,k,v);
    eta_sum = eta_sum + sqrt(2*Setak*dOmegak)*cos(omegak*t_sim+rand_vec(j,k));
    
    Setak_original = S_eta_original(n,n,k,v);
    eta_sum_original = eta_sum_original + sqrt(2*Setak_original*dOmegak)*cos(omegak*t_sim+rand_vec(j,k));
 end
 eta_n(:,n) = eta_sum;
 eta_orig_n(:,n)  = eta_sum_original;
 end
 for m = 1:N_j
      eta_sum_rd = zeros(1,t_simn);
  for k=1:length(Omega)
    omegak=Omega(k);
    dOmegak = dOmega(k);
    Setak_rd = S_eta_rd(m,k,v); 
    eta_sum_rd = eta_sum_rd + sqrt(2*Setak_rd*dOmegak)*cos(omegak*t_sim+rand_vec(j,k));
  end
  eta_rd_n(:,m) = eta_sum_rd;
 end

 r_z_sum_of_modes = zeros(length(xval),t_simn);
 r_z_sum_of_modes_original = zeros(length(xval),t_simn);
 r_d_sum_of_modes = zeros(t_simn,N_j);
 
 for x = 1:length(xval)
for n = 1:N_mod
    r_z_sum_of_modes(x,:) = r_z_sum_of_modes(x,:) + phi_mode(x,n)*transpose(eta_n(:,n));
    r_z_sum_of_modes_original(x,:) = r_z_sum_of_modes_original(x,:) + phi_mode(x,n)*transpose(eta_orig_n(:,n));
end
 end 
for m = 1:N_j
     r_d_sum_of_modes(:,m) = 1*transpose(eta_rd_n(:,m));
end

  damper_displacement_x = zeros(N_j);

for xr = 1:N_j
damper_displacement_x(xr) = x_d(xr);
%max_y = max(max(abs(eta_rd_n(:,m))));
end
rz_orig_plot = rz_orig(:,1:length(t_sim),:,:);
max_y_orig = max(max(abs(r_z_sum_of_modes_original)));
maxy_rz = max(max(abs(r_z_sum_of_modes))); 
maxy_damper = max(max(abs(r_d_sum_of_modes)));

% Sum of modes:
[rz_distr_x, rz_distr_x_orig] = SumOfModes(rand_vec,phi_d,S_eta,S_eta_original,Sr_rz,Sr_original,phi_mode,xval,v,N_mod,N_j,j,t_sim,Omega,dOmega);
% Original response, several points:
[rz_orig_for_multiple_xr,x_points] = OriginalResponseSeveralPoints(xval,N_mod,Omega,dOmega,t_sim,rho,B,mz_vec,v,Kaz,j,xi_z,aL,D,omega_z,sigma_qz_hatt,Omega_s,bz,Vr,lambda,int_phi_z_sq,phi_z,Kzinv,rand_vec); 

maxY = 1.05*max(max(max_y_orig,maxy_rz+maxy_damper));
fig = figure;
 writerObj = VideoWriter(['MatLabOutPutFiles\TMDmmResponceTimeSimulationMovieVR ' num2str(v) ' TotCaseNr ' num2str(TotCaseNr) '.avi']);
open(writerObj)
       for t = 1:t_simn
           max_y_orig_current = max(abs(r_z_sum_of_modes_original(:,t)));
           max_y_rz_current = max(abs(r_z_sum_of_modes(:,t)));
           
   subplot(2,1,1)
   p = plot(xval,real(r_z_sum_of_modes_original(:,t)),xval,real(rz_distr_x_orig(:,t)),'r');
            axis([0 L -maxY maxY])
                str1=['Time:' num2str(round(10*t_sim(t))/10) 's'];
                text(L/2,0.7*maxY,str1,'Fontsize',14)
                    str2=['Max deflection in ' num2str(round(10*t_sim(end))/10) ' s time window = ' num2str(round(1000*max_y_orig)/1000) ' m '];
                    text(L/20,-0.83*maxY,str2,'Fontsize',14)
                    str3=['Max current deflection = ' num2str(round(1000*max_y_orig_current)/1000) ' m '];
                    text(6*L/10,-0.83*maxY,str3,'Fontsize',14) 
                    set(gca,'Fontsize',14,'LineWidth',1)
                    hTitle = title(['Simulated main system response without TMD, Case ' num2str(TotCaseNr) ' , $$V_{cr}$$ = ' num2str(round(1000*Vr(v))/1000) ' m/s ']);
                    hYLabel = ylabel('$$r_{z}$$  [m]');
                    hYLabelProperties(hYLabel);
                    FigAndTitleProperties(fig, hTitle)
                    pPlotProperties(p);
                    hold on
    for xr = 1:N_j
    scatter(damper_displacement_x(xr),rz_orig_plot(j,t,xr,v));
    end
    for xr = 1:length(x_points)
    scatter(x_points(xr),rz_orig_for_multiple_xr(xr,t),'r');
    end
    hold off
   subplot(2,1,2)
   p = plot(xval,real(r_z_sum_of_modes(:,t)),xval,rz_distr_x(:,t),'r'); %xval,real(rz_distr_x(t,:,j,v)),
        hold on
            axis([0 L -maxY maxY])
                    str4=['Bridge girder = ' num2str(round(1000*maxy_rz)/1000) ' m '];
                    text(L/30,-0.67*maxY,str4,'Fontsize',14)
                    str5=['Bridge girder = ' num2str(round(1000*max_y_rz_current)/1000) ' m '];
                    text(6*L/10,-0.67*maxY,str5,'Fontsize',14)
                    
                set(gca,'Fontsize',14,'LineWidth',1)
                hTitle = title('Simulated main system and TMD response');
                hYLabel = ylabel('$$r_{z}$$ and $$r_{d}$$  [m]');
                hXLabel = xlabel('Spanwidth   [m]');
                str1=['Time:' num2str(round(10*t_sim(t))/10) 's'];
                text(L/2,0.7*maxY,str1,'Fontsize',14)
                PlotProperties(fig, p, hTitle, hXLabel, hYLabel);
                
            max_y_damper_current = zeros(1,N_j);
    for xr = 1:N_j
        xpos = floor(x_d(xr)/(xval(end)/length(xval)));
       max_y_damper_current(xr) = max(abs(real(r_d_sum_of_modes(t,xr)+r_z_sum_of_modes(xpos,t))));
    scatter(damper_displacement_x(xr),real(r_d_sum_of_modes(t,xr)+r_z_sum_of_modes(xpos,t)),'filled');
    axis([0 L -maxY maxY])
    end
                    current_max_y_damp = max(max_y_damper_current);
                    str6=['Max deflection in ' num2str(round(10*t_sim(end))/10) ' s time window of: '];
                    text(L/30,-0.5*maxY,str6,'Fontsize',14)
                    str7=['TMD(s) (relative defl.) = ' num2str(round(1000*maxy_damper)/1000) ' m '];
                    text(L/30,-0.85*maxY,str7,'Fontsize',14)
                    str8=['Max current deflection of: '];
                    text(6*L/10,-0.5*maxY,str8,'Fontsize',14)
                    str9=['TMD(s) (relative defl.) = ' num2str(round(1000*current_max_y_damp)/1000) ' m '];
                    text(6*L/10,-0.85*maxY,str9,'Fontsize',14)
          frame = getframe(fig);
      hold off
    writeVideo(writerObj,frame);
       end
  close(writerObj);
 %movie(frame,1,1)
end
 end
 



Information_matrix(TotCaseNr,1) = TotCaseNr;
Information_matrix(TotCaseNr,2) = N_j;
Information_matrix(TotCaseNr,3:2+N_j) = x_d;
Information_matrix(TotCaseNr,6:5+N_j) = TMD_mode_damp;
Information_matrix(TotCaseNr,9:8+N_j) = my_d;
Information_matrix(TotCaseNr,12:11+N_j) = xi_d;
Information_matrix(TotCaseNr,15:14+N_j) = omega_d;

    end
end

% Plotting the FRF at:
Hplot(H_rz,TotCaseNr)
